==> slapos.cookbook-0.56-dev.tar.gz: slapos.cookbook-0.56-dev/slapos/recipe/slapmonitor/__init__.py <==
##############################################################################
#
# Copyright (c) 2011 Vifib SARL and Contributors. All Rights Reserved.
#
# WARNING: This program as such is intended to be used by professional
# programmers who take the whole responsibility of assessing all potential
# consequences resulting from its eventual inadequacies and bugs
# End users who are looking for a ready-to-use solution with commercial
# guarantees and support are strongly adviced to contract a Free Software
# Service Company
#
# This program is Free Software; you can redistribute it and/or
# modify it under the terms of the GNU General Public License
# as published by the Free Software Foundation; either version 3
# of the License, or (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
#
##############################################################################
from slapos.recipe.librecipe import GenericBaseRecipe

class Recipe(GenericBaseRecipe):
  """
  Slapmonitor instance configuration.
  """

  def __init__(self, buildout, name, options):
    return GenericBaseRecipe.__init__(self, buildout, name, options)

  def install(self):
    config = dict(
      pid_file_path=self.options['pid-file'],
      database_path=self.options['database-path'],
      slapmonitor_path = self.options['slapmonitor-path'],
      shell_path=self.options['shell-path'],
    )

    # Runners
    runner_path = self.createExecutable(
      self.options['path'],
      self.substituteTemplate(self.getTemplateFilename('slapmonitor_run.in'),
                              config))

    return [runner_path]

  def update(self):
    pass

==> slapos.cookbook-0.75.0.tar.gz: slapos.cookbook-0.75.0/slapos/recipe/slapmonitor/__init__.py <==
##############################################################################
#
# Copyright (c) 2011 Vifib SARL and Contributors. All Rights Reserved.
#
# WARNING: This program as such is intended to be used by professional
# programmers who take the whole responsibility of assessing all potential
# consequences resulting from its eventual inadequacies and bugs
# End users who are looking for a ready-to-use solution with commercial
# guarantees and support are strongly adviced to contract a Free Software
# Service Company
#
# This program is Free Software; you can redistribute it and/or
# modify it under the terms of the GNU General Public License
# as published by the Free Software Foundation; either version 3
# of the License, or (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
#
##############################################################################

from slapos.recipe.librecipe import GenericBaseRecipe

class MonitorRecipe(GenericBaseRecipe):

  def install(self):
    options = self.options
    script = self.createWrapper(name=options['path'],
                                command=options['slapmonitor-path'],
                                parameters=[
                                    options['pid-file'],
                                    options['database-path'],
                                    ])
    return [script]


class MonitorXMLRecipe(GenericBaseRecipe):

  def install(self):
    options = self.options
    script = self.createWrapper(name=options['path'],
                                command=options['slapmonitor-xml-path'],
                                parameters=[
                                    options['database-path'],
                                    ],
                                parameters_extra=True)
    return [script]
